You are viewing a plain text version of this content. The canonical link for it is here.
Posted to issues@maven.apache.org by GitBox <gi...@apache.org> on 2018/12/28 15:25:33 UTC

[GitHub] michael-o closed pull request #103: spelling: excident

michael-o closed pull request #103: spelling: excident
URL: https://github.com/apache/maven/pull/103
 
 
   

This is a PR merged from a forked repository.
As GitHub hides the original diff on merge, it is displayed below for
the sake of provenance:

As this is a foreign pull request (from a fork), the diff is supplied
below (as it won't show otherwise due to GitHub magic):

diff --git a/maven-compat/src/main/java/org/apache/maven/repository/MetadataGraphNode.java b/maven-compat/src/main/java/org/apache/maven/repository/MetadataGraphNode.java
index c258f05a6e..db9c9355f3 100644
--- a/maven-compat/src/main/java/org/apache/maven/repository/MetadataGraphNode.java
+++ b/maven-compat/src/main/java/org/apache/maven/repository/MetadataGraphNode.java
@@ -23,7 +23,7 @@
 import java.util.List;
 
 /**
  * MetadataGraph node - as it's a directed graph - holds adjacency lists for incident and exident nodes
  *
  * @author Oleg Gusakov
  *
@@ -36,7 +36,7 @@
     /** nodes, incident to this (depend on me) */
     List<MetadataGraphNode> inNodes;
 
     /** nodes, exident to this (I depend on) */
     List<MetadataGraphNode> exNodes;
 
     public MetadataGraphNode()
@@ -57,7 +57,7 @@ public MetadataGraphNode addIncident( MetadataGraphNode node )
         return this;
     }
 
-    public MetadataGraphNode addExident( MetadataGraphNode node )
+    public MetadataGraphNode addExcident( MetadataGraphNode node )
     {
         exNodes.add( node );
         return this;


 

----------------------------------------------------------------
@@ -23,7 +23,7 @@
 
 /**
- * MetadataGraph node - as it's a directed graph - holds adjacency lists for incident and exident nodes
+ * MetadataGraph node - as it's a directed graph - holds adjacency lists for incident and excident nodes
  *
  * @author Oleg Gusakov
@@ -36,7 +36,7 @@
     List<MetadataGraphNode> inNodes;
 
-    /** nodes, exident to this (I depend on) */
+    /** nodes, excident to this (I depend on) */
     List<MetadataGraphNode> exNodes;
 
This is an automated message from the Apache Git Service.
To respond to the message, please log on GitHub and use the
URL above to go to the specific comment.
 
For queries about this service, please contact Infrastructure at:
users@infra.apache.org


With regards,
Apache Git Services